==> apache-seatunnel-2.3.2-src.tar.gz: apache-seatunnel-2.3.2-src/seatunnel-connectors-v2/connector-jdbc/src/test/java/org/apache/seatunnel/connectors/seatunnel/jdbc/catalog/SnowflakeDataTypeConvertorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.jdbc.catalog;

import org.apache.seatunnel.api.table.type.BasicType;
import org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.snowflake.SnowflakeDataTypeConvertor;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import net.snowflake.client.jdbc.SnowflakeType;

import java.util.Collections;

public class SnowflakeDataTypeConvertorTest {
    private final SnowflakeDataTypeConvertor snowflakeDataTypeConvertor =
            new SnowflakeDataTypeConvertor();

    @Test
    public void toSeaTunnelType() {

        Assertions.assertEquals(
                BasicType.STRING_TYPE,
                snowflakeDataTypeConvertor.toSeaTunnelType(
                        SnowflakeType.TEXT.name(), Collections.emptyMap()));

        Assertions.assertEquals(
                BasicType.STRING_TYPE,
                snowflakeDataTypeConvertor.toSeaTunnelType(
                        SnowflakeType.VARIANT.name(), Collections.emptyMap()));

        Assertions.assertEquals(
                BasicType.STRING_TYPE,
                snowflakeDataTypeConvertor.toSeaTunnelType(
                        SnowflakeType.OBJECT.name(), Collections.emptyMap()));
    }
}

==> apache-seatunnel-2.3.4-src.tar.gz: apache-seatunnel-2.3.4-src/seatunnel-connectors-v2/connector-jdbc/src/test/java/org/apache/seatunnel/connectors/seatunnel/jdbc/catalog/SnowflakeDataTypeConvertorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.jdbc.catalog;

import org.apache.seatunnel.api.table.type.BasicType;
import org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.snowflake.SnowflakeDataTypeConvertor;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import net.snowflake.client.jdbc.SnowflakeType;

import java.util.Collections;

public class SnowflakeDataTypeConvertorTest {
    private final SnowflakeDataTypeConvertor snowflakeDataTypeConvertor =
            new SnowflakeDataTypeConvertor();

    @Test
    public void toSeaTunnelType() {

        Assertions.assertEquals(
                BasicType.STRING_TYPE,
                snowflakeDataTypeConvertor.toSeaTunnelType(
                        "", SnowflakeType.TEXT.name(), Collections.emptyMap()));

        Assertions.assertEquals(
                BasicType.STRING_TYPE,
                snowflakeDataTypeConvertor.toSeaTunnelType(
                        "", SnowflakeType.VARIANT.name(), Collections.emptyMap()));

        Assertions.assertEquals(
                BasicType.STRING_TYPE,
                snowflakeDataTypeConvertor.toSeaTunnelType(
                        "", SnowflakeType.OBJECT.name(), Collections.emptyMap()));
    }
}
